#!/bin/sh
# Installation script for the ddptools package
# Author: Andreas Ruge

INSTALL=install
INSTALL_PROGRAM="${INSTALL} -m 755"
INSTALL_DATA="${INSTALL} -m 644"

# GNU standard directory variables
# (see GNU Makefile manual)
: ${prefix:="/usr/local"}
exec_prefix=${prefix}
bindir=${exec_prefix}/bin
datarootdir=${prefix}/share
datadir=${prefix}/share/ddptools
mandir=${prefix}/share/man
man1dir=${mandir}/man1

# The binaries to be installed, each with a manpage
DDPTOOLS="ddpinfo cue2ddp cdtinfo"
UNINSTALLER=${DESTDIR}${bindir}/ddptools-uninstall
# collect filenames while installing
FILES=


create_uninstaller() {
    cat > ${UNINSTALLER} <<EOF
#!/bin/sh

echo -n "Do you want to uninstall ddptools from '${prefix}' (y/n)? "
read answer
if [ "\$answer" != "y" ] ; then
    exit 0
fi

if [ ! -w "${prefix}" ] ; then
    echo "You don't have permission to write to '${prefix}'. Are you root?"
    exit 1
fi

EOF
    for file in ${FILES} ; do
        echo "rm ${file}" >> ${UNINSTALLER}
    done
    echo "echo Uninstallation completed" >> ${UNINSTALLER}
    chmod 755 ${UNINSTALLER}
}


usage() {
    cat <<EOF
Usage:  
        [sudo] [DESTDIR=<DIRECTORY>] [prefix=<DIRECTORY>] ./install.sh [options]

Description: 
    Install the ddptools package, run this script as root. The default
    prefix is '/usr/local' and root privileges are required for the
    installation.

    Successful installation can be checked by running

        $ cue2ddp --version

    Set the 'prefix' environment variable to install to a different 
    location, e.g.

        $ sudo prefix=/home/luke ./install.sh

    Set the 'DESTDIR' environment variable to install to a specific
    build-root as need for packaging.

Uninstall:
    Uninstall the ddptools by running

        sudo ddptools-uninstall

    which will remove all files previously installed.

Options:
    --help            Print this help and exit.
    --no-uninstaller  Install ddptools but do not create an uninstaller.
EOF
}


do_install() {
    #echo "Installing ddptools to ${DESTDIR}${prefix}"

    # make diretories
    ${INSTALL_PROGRAM} -d ${DESTDIR}${bindir} ${DESTDIR}${man1dir}

    for tool in ${DDPTOOLS} ; do

        # binary
        ${INSTALL_PROGRAM} ${tool} ${DESTDIR}${bindir}
        FILES="$FILES ${DESTDIR}${bindir}/${tool}"

	# manpage
        ${INSTALL_DATA} doc/${tool}.1 ${DESTDIR}${man1dir}
        gzip -9 -f ${DESTDIR}${man1dir}/${tool}.1
        FILES="$FILES ${DESTDIR}${man1dir}/${tool}.1.gz"
    done

    if [ "$UNINSTALLER" != "" ] ; then
    	create_uninstaller
    fi
}

# Start processing
if [ -z "$1" ]
then
    echo
    do_install
elif [ "$1" = "--no-uninstaller" ]
then
    UNINSTALLER= 
    do_install
elif [ "$1" = "--help" ]
then
    usage
else
    echo "Error: unknown argument"
    usage
exit 1
fi
